@@ -19,7 +19,6 @@ from pathlib import Path
 from copy import copy, deepcopy
 
 import oyaml as yaml
-import shortuuid
 
 import dash
 import dash_auth
@@ -34,7 +33,7 @@ from jupyter_dash import JupyterDash
 
 import plotly.io as pio
 
-from .dashboard_methods import instantiate_component
+from .dashboard_methods import instantiate_component, encode_callables, decode_callables
 from .dashboard_components import *
 from .dashboard_tabs import *
 from .explainers import BaseExplainer
@@ -246,34 +245,36 @@ class ExplainerPageLayout(ExplainerComponent):
 
 
 class ExplainerDashboard:
-    def __init__(self, explainer=None, tabs=None,
-                 title='Model Explainer',
-                 name=None,
-                 description=None,
-                 hide_header=False,
-                 header_hide_title=False,
-                 header_hide_selector=False,
-                 hide_poweredby=False,
-                 block_selector_callbacks=False,
-                 pos_label=None,
-                 fluid=True,
-                 mode="dash",
-                 width=1000,
-                 height=800,
-                 bootstrap=None,
-                 external_stylesheets=None,
-                 server=True,
-                 url_base_pathname=None,
-                 responsive=True,
-                 logins=None,
-                 port=8050,
-                 importances=True,
-                 model_summary=True,
-                 contributions=True,
-                 whatif=True,
-                 shap_dependence=True,
-                 shap_interaction=True,
-                 decision_trees=True,
+    def __init__(self, 
+                 explainer:BaseExplainer=None, 
+                 tabs:Union[ExplainerComponent, List[ExplainerComponent]]=None,
+                 title:str='Model Explainer',
+                 name:str=None,
+                 description:str=None,
+                 hide_header:bool=False,
+                 header_hide_title:bool=False,
+                 header_hide_selector:bool=False,
+                 hide_poweredby:bool=False,
+                 block_selector_callbacks:bool=False,
+                 pos_label:Union[str, int]=None,
+                 fluid:bool=True,
+                 mode:str="dash",
+                 width:int=1000,
+                 height:int=800,
+                 bootstrap:str=None,
+                 external_stylesheets:List[str]=None,
+                 server:bool=True,
+                 url_base_pathname:str=None,
+                 responsive:bool=True,
+                 logins:List[List[str]]=None,
+                 port:int=8050,
+                 importances:bool=True,
+                 model_summary:bool=True,
+                 contributions:bool=True,
+                 whatif:bool=True,
+                 shap_dependence:bool=True,
+                 shap_interaction:bool=True,
+                 decision_trees:bool=True,
                  **kwargs):
         """Creates an explainerdashboard out of an Explainer object.
 
@@ -361,6 +362,7 @@ class ExplainerDashboard:
 
         self._store_params(no_param=['explainer', 'tabs', 'server'])
         self._stored_params['tabs'] = self._tabs_to_yaml(tabs)
+
         if not hasattr(explainer, "__version__"):
             raise ValueError(f"The {explainer.__class__.__name__} was generated "
                     "with a version of explainerdashboard<0.3 and therefore not "
@@ -403,14 +405,6 @@ class ExplainerDashboard:
             else:
                 self.external_stylesheets.append(bootstrap_theme)
 
-        if not hasattr(self.explainer, "onehot_dict"):
-            # explainer generated with explainerdashboard < v0.2.20
-            self.explainer.onehot_dict = self.explainer.cats_dict
-            self.explainer.onehot_cols = self.explainer.cats
-            self.explainer.cat_cols = self.explainer.cats
-            self.explainer.categorical_cols = []
-            self.explainer.categorical_dict = {}
-
         self.app = self._get_dash_app()
 
         if logins is not None:
@@ -469,31 +463,38 @@ class ExplainerDashboard:
 
         if isinstance(tabs, list) and len(tabs)==1:
             tabs = tabs[0]
-        print("Generating layout...")  
+
+        print("Generating layout...") 
+        _, i = yield_id(return_i=True) # store id generator index
+        reset_id_generator("db") # reset id generator to 0 with prefix "db"
+        if hasattr(self.explainer, "_index_list"):
+            del self.explainer._index_list # delete cached ._index_list to force re-download
+
         if isinstance(tabs, list):
             tabs = [self._convert_str_tabs(tab) for tab in tabs]
             self.explainer_layout = ExplainerTabsLayout(explainer, tabs, title, 
                             description=self.description,
                             **update_kwargs(kwargs, 
-                            header_hide_title=self.header_hide_title, 
-                            header_hide_selector=self.header_hide_selector, 
-                            hide_poweredby=self.hide_poweredby,
-                            block_selector_callbacks=self.block_selector_callbacks,
-                            pos_label=self.pos_label,
-                            fluid=fluid))
+                                header_hide_title=self.header_hide_title, 
+                                header_hide_selector=self.header_hide_selector, 
+                                hide_poweredby=self.hide_poweredby,
+                                block_selector_callbacks=self.block_selector_callbacks,
+                                pos_label=self.pos_label,
+                                fluid=fluid))
         else:
             tabs = self._convert_str_tabs(tabs)
             self.explainer_layout = ExplainerPageLayout(explainer, tabs, title,
                             description=self.description, 
                             **update_kwargs(kwargs,
-                            header_hide_title=self.header_hide_title, 
-                            header_hide_selector=self.header_hide_selector, 
-                            hide_poweredby=self.hide_poweredby,
-                            block_selector_callbacks=self.block_selector_callbacks,
-                            pos_label=self.pos_label,
-                            fluid=self.fluid))
+                                header_hide_title=self.header_hide_title, 
+                                header_hide_selector=self.header_hide_selector, 
+                                hide_poweredby=self.hide_poweredby,
+                                block_selector_callbacks=self.block_selector_callbacks,
+                                pos_label=self.pos_label,
+                                fluid=self.fluid))
 
         self.app.layout = self.explainer_layout.layout()
+        reset_id_generator(start=i+1) # reset id generator to previous index
 
         print("Calculating dependencies...", flush=True)  
         self.explainer_layout.calculate_dependencies()
@@ -563,7 +564,7 @@ class ExplainerDashboard:
                     "When passing two arguments to ExplainerDashboard.from_config(arg1, arg2), "
                     "arg2 should be a .yaml file or a dict!")
 
-        dashboard_params = config['dashboard']['params']
+        dashboard_params = decode_callables(config['dashboard']['params'])
 
         for k, v in update_params.items():
             if k in dashboard_params:
@@ -673,6 +674,8 @@ class ExplainerDashboard:
             if not dont_param and name not in no_store and name not in no_param:
                 self._stored_params[name] = value
 
+        self._stored_params = encode_callables(self._stored_params)
+
     def _convert_str_tabs(self, component):
         if isinstance(component, str):
             if component == 'importances':
@@ -747,6 +750,8 @@ class ExplainerDashboard:
                 else:
                     if not 'name' in tab['params'] or tab['params']['name'] is None:
                         tab['params']['name'] = name
+
+                    tab['params'] = decode_callables(tab['params'])
                     tab_instance = tab_class(explainer, **tab['params'])
                     return tab_instance
             else:
@@ -839,7 +844,7 @@ class ExplainerDashboard:
             else:
                 app = self.app
 
-            print(f"Starting ExplainerDashboard on http://localhost:{port}", flush=True)
+            print(f"Starting ExplainerDashboard on http://{get_local_ip_adress()}:{port}", flush=True)
             if use_waitress:
                 from waitress import serve
                 serve(app.server, host=host, port=port)
@@ -855,7 +860,7 @@ class ExplainerDashboard:
                 app = self.app
             if mode == 'external':
                 if not self.is_colab:
-                    print(f"Starting ExplainerDashboard on http://localhost:{port}\n"
+                    print(f"Starting ExplainerDashboard on http://{get_local_ip_adress()}:{port}\n"
                         "You can terminate the dashboard with "
                         f"ExplainerDashboard.terminate({port})", flush=True)
                 app.run_server(port=port, mode=mode, **kwargs)
@@ -1706,7 +1711,7 @@ class ExplainerHub:
         """
         if port is None:
             port = self.port
-        print(f"Starting ExplainerHub on http://{host}:{port}", flush=True)
+        print(f"Starting ExplainerHub on http://{get_local_ip_adress()}:{port}", flush=True)
         if use_waitress:
             import waitress
             waitress.serve(self.app, host=host, port=port, **kwargs)  
